Documentation
¶
Overview ¶
Package heyrafiki provides a typed, server-side client for the Heyrafiki API.
Index ¶
- type APIError
- type APIInformation
- type APIService
- type ApprovedPreauthorizationDecisionInput
- type AuthStyle
- type AvailabilityWindow
- type Booking
- type BookingInput
- type BookingList
- type BookingService
- func (service *BookingService) Create(ctx context.Context, input BookingInput, options WriteOptions) (*Booking, error)
- func (service *BookingService) List(ctx context.Context, options *ListOptions) (*BookingList, error)
- func (service *BookingService) Retrieve(ctx context.Context, bookingID string) (*Booking, error)
- type CareFormat
- type Claim
- type ClaimAdjudication
- type ClaimAdjudicationAmounts
- type ClaimAdjudicationInput
- type ClaimAdjudicationLine
- type ClaimAdjudicationTotal
- type ClaimAmount
- type ClaimEvidenceInput
- type ClaimInformationRequest
- type ClaimInformationRequestInput
- type ClaimInput
- type ClaimLine
- type ClaimLineInput
- type ClaimList
- type ClaimService
- func (service *ClaimService) Adjudicate(ctx context.Context, claimID string, input ClaimAdjudicationInput, ...) (*Claim, error)
- func (service *ClaimService) Create(ctx context.Context, input ClaimInput, options WriteOptions) (*Claim, error)
- func (service *ClaimService) List(ctx context.Context, options *ListOptions) (*ClaimList, error)
- func (service *ClaimService) RequestInformation(ctx context.Context, claimID string, input ClaimInformationRequestInput, ...) (*Claim, error)
- func (service *ClaimService) Retrieve(ctx context.Context, claimID string) (*Claim, error)
- func (service *ClaimService) SubmitEvidence(ctx context.Context, claimID string, input ClaimEvidenceInput, ...) (*Claim, error)
- func (service *ClaimService) Valuation(ctx context.Context, claimID string, options ClaimValuationOptions) (*ClaimValuation, error)
- type ClaimValuation
- type ClaimValuationAmount
- type ClaimValuationEvent
- type ClaimValuationOptions
- type Client
- type CoverageAmountLimit
- type CoverageBatchInput
- type CoverageBatchOptions
- type CoverageBatchRecordInput
- type CoverageBatchResult
- type CoverageBatchService
- type CoverageObservation
- type CoverageObservationInput
- type CoverageService
- type CoverageStatus
- type Currency
- type DeniedPreauthorizationDecisionInput
- type EligibilityAmount
- type EligibilityCheck
- type EligibilityCheckInput
- type EligibilityCheckService
- type EligibilityService
- type ListOptions
- type Money
- type Option
- type PaymentSource
- type PolicyReference
- type Practitioner
- type PractitionerAvailability
- type PractitionerList
- type PractitionerLocation
- type PractitionerService
- func (service *PractitionerService) Availability(ctx context.Context, practitionerID string) (*PractitionerAvailability, error)
- func (service *PractitionerService) List(ctx context.Context, options *ListOptions) (*PractitionerList, error)
- func (service *PractitionerService) Retrieve(ctx context.Context, practitionerID string) (*Practitioner, error)
- type Preauthorization
- type PreauthorizationAmount
- type PreauthorizationDecision
- type PreauthorizationDecisionInput
- type PreauthorizationInput
- type PreauthorizationService
- func (service *PreauthorizationService) Create(ctx context.Context, input PreauthorizationInput, options WriteOptions) (*Preauthorization, error)
- func (service *PreauthorizationService) Decide(ctx context.Context, preauthorizationID string, ...) (*Preauthorization, error)
- func (service *PreauthorizationService) Retrieve(ctx context.Context, preauthorizationID string) (*Preauthorization, error)
- type Remittance
- type RemittanceAllocation
- type RemittanceAllocationInput
- type RemittanceAmount
- type RemittanceInput
- type RemittanceList
- type RemittanceService
- func (service *RemittanceService) Create(ctx context.Context, input RemittanceInput, options WriteOptions) (*Remittance, error)
- func (service *RemittanceService) List(ctx context.Context, options *ListOptions) (*RemittanceList, error)
- func (service *RemittanceService) Retrieve(ctx context.Context, remittanceID string) (*Remittance, error)
- type RetryPolicy
- type ServicePeriod
- type Session
- type SessionList
- type SessionService
- type WebhookDelivery
- type WebhookEndpoint
- type WebhookEndpointInput
- type WebhookEndpointList
- type WebhookEndpointService
- func (service *WebhookEndpointService) Create(ctx context.Context, input WebhookEndpointInput) (*WebhookEndpointWithSecret, error)
- func (service *WebhookEndpointService) Disable(ctx context.Context, endpointID string) (*WebhookEndpoint, error)
- func (service *WebhookEndpointService) List(ctx context.Context, options *ListOptions) (*WebhookEndpointList, error)
- func (service *WebhookEndpointService) Retrieve(ctx context.Context, endpointID string) (*WebhookEndpoint, error)
- func (service *WebhookEndpointService) SendTest(ctx context.Context, endpointID string) (*WebhookDelivery, error)
- type WebhookEndpointWithSecret
- type WebhookEvent
- type WriteOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type APIError ¶
type APIError struct {
StatusCode int
Code string
Message string
RequestID string
Docs string
RetryAfter time.Duration
// contains filtered or unexported fields
}
APIError represents the documented Heyrafiki API error envelope.
type APIInformation ¶
type APIService ¶
type APIService struct {
// contains filtered or unexported fields
}
APIService reads API metadata.
func (*APIService) Retrieve ¶
func (service *APIService) Retrieve(ctx context.Context) (*APIInformation, error)
Retrieve returns API version and environment information.
type ApprovedPreauthorizationDecisionInput ¶
type ApprovedPreauthorizationDecisionInput struct {
}
type AuthStyle ¶
type AuthStyle string
AuthStyle selects one of the authentication schemes published by the API contract.
type AvailabilityWindow ¶
type AvailabilityWindow struct {
Weekday int `json:"weekday"`
Start string `json:"start"`
End string `json:"end"`
Formats []CareFormat `json:"formats"`
}
type Booking ¶
type Booking struct {
ID string `json:"id"`
Object string `json:"object"`
SessionID string `json:"session_id"`
PractitionerID string `json:"practitioner_id"`
StartsAt string `json:"starts_at"`
EndsAt string `json:"ends_at"`
Timezone string `json:"timezone"`
Format CareFormat `json:"format"`
Status string `json:"status"`
PaymentSource PaymentSource `json:"payment_source"`
}
type BookingInput ¶
type BookingInput struct {
PractitionerID string `json:"practitioner_id"`
StartsAt string `json:"starts_at"`
EndsAt string `json:"ends_at"`
Format CareFormat `json:"format"`
PaymentSource PaymentSource `json:"payment_source"`
}
type BookingList ¶
type BookingService ¶
type BookingService struct {
// contains filtered or unexported fields
}
BookingService creates and reads Bookings.
func (*BookingService) Create ¶
func (service *BookingService) Create(ctx context.Context, input BookingInput, options WriteOptions) (*Booking, error)
Create creates a Booking with a caller-owned idempotency key.
func (*BookingService) List ¶
func (service *BookingService) List(ctx context.Context, options *ListOptions) (*BookingList, error)
List returns Bookings visible to the project.
type CareFormat ¶
type CareFormat string
CareFormat identifies how a Session takes place.
const ( CareFormatOnline CareFormat = "online" CareFormatInPerson CareFormat = "in_person" CareFormatPhone CareFormat = "phone" )
type Claim ¶
type Claim struct {
ID string `json:"id"`
Object string `json:"object"`
Status string `json:"status"`
ProviderClaimReference *string `json:"provider_claim_reference"`
SubmissionVersion int `json:"submission_version"`
Amount ClaimAmount `json:"amount"`
ServicePeriod ServicePeriod `json:"service_period"`
Lines []ClaimLine `json:"lines"`
InformationRequests []ClaimInformationRequest `json:"information_requests"`
Adjudication *ClaimAdjudication `json:"adjudication"`
SubmittedAt *string `json:"submitted_at"`
UpdatedAt string `json:"updated_at"`
}
type ClaimAdjudication ¶
type ClaimAdjudication struct {
ID string `json:"id"`
Object string `json:"object"`
Version int `json:"version"`
Decision string `json:"decision"`
Amount ClaimAdjudicationTotal `json:"amount"`
ReasonCodes []string `json:"reason_codes"`
Policy PolicyReference `json:"policy"`
Lines []ClaimAdjudicationLine `json:"lines"`
DecidedAt string `json:"decided_at"`
}
type ClaimAdjudicationInput ¶
type ClaimAdjudicationInput struct {
PolicyReference string `json:"policy_reference"`
PolicyVersion string `json:"policy_version"`
ReasonCodes []string `json:"reason_codes"`
EvidenceRefs []string `json:"evidence_refs,omitempty"`
Lines []ClaimAdjudicationLine `json:"lines"`
}
type ClaimAdjudicationLine ¶
type ClaimAdjudicationLine struct {
LineNumber int `json:"line_number"`
Amount ClaimAdjudicationAmounts `json:"amount"`
ReasonCodes []string `json:"reason_codes"`
}
type ClaimAdjudicationTotal ¶
type ClaimAmount ¶
type ClaimEvidenceInput ¶
type ClaimInformationRequest ¶
type ClaimInformationRequest struct {
ID string `json:"id"`
Object string `json:"object"`
ReasonCode string `json:"reason_code"`
RequestedEvidenceTypes []string `json:"requested_evidence_types"`
Status string `json:"status"`
DueAt *string `json:"due_at"`
CreatedAt string `json:"created_at"`
ResolvedAt *string `json:"resolved_at"`
}
type ClaimInput ¶
type ClaimInput struct {
EligibilityCheckID string `json:"eligibility_check_id"`
SessionID string `json:"session_id"`
ProviderClaimReference string `json:"provider_claim_reference"`
EvidenceRefs []string `json:"evidence_refs,omitempty"`
Lines []ClaimLineInput `json:"lines"`
}
type ClaimLineInput ¶
type ClaimService ¶
type ClaimService struct {
// contains filtered or unexported fields
}
ClaimService creates and manages Claims.
func (*ClaimService) Adjudicate ¶
func (service *ClaimService) Adjudicate(ctx context.Context, claimID string, input ClaimAdjudicationInput, options WriteOptions) (*Claim, error)
Adjudicate records a Claim adjudication decision.
func (*ClaimService) Create ¶
func (service *ClaimService) Create(ctx context.Context, input ClaimInput, options WriteOptions) (*Claim, error)
Create submits a Claim with a caller-owned idempotency key.
func (*ClaimService) List ¶
func (service *ClaimService) List(ctx context.Context, options *ListOptions) (*ClaimList, error)
List returns Claims visible to the project.
func (*ClaimService) RequestInformation ¶
func (service *ClaimService) RequestInformation(ctx context.Context, claimID string, input ClaimInformationRequestInput, options WriteOptions) (*Claim, error)
RequestInformation records a payer request for Claim evidence.
func (*ClaimService) SubmitEvidence ¶
func (service *ClaimService) SubmitEvidence(ctx context.Context, claimID string, input ClaimEvidenceInput, options WriteOptions) (*Claim, error)
SubmitEvidence attaches evidence references to a Claim information request.
func (*ClaimService) Valuation ¶
func (service *ClaimService) Valuation(ctx context.Context, claimID string, options ClaimValuationOptions) (*ClaimValuation, error)
Valuation reproduces a Claim valuation from the facts known at an inclusive cutoff.
type ClaimValuation ¶
type ClaimValuation struct {
ID string `json:"id"`
Object string `json:"object"`
ClaimID string `json:"claim_id"`
ValuationAt string `json:"valuation_at"`
Currency string `json:"currency"`
Status string `json:"status"`
Amount ClaimValuationAmount `json:"amount"`
Policy *PolicyReference `json:"policy"`
Events []ClaimValuationEvent `json:"events"`
}
type ClaimValuationAmount ¶
type ClaimValuationAmount struct {
Billed int64 `json:"billed"`
PayerLiability *int64 `json:"payer_liability"`
PatientResponsibility *int64 `json:"patient_responsibility"`
Adjustment *int64 `json:"adjustment"`
Remitted int64 `json:"remitted"`
Settled int64 `json:"settled"`
Outstanding *int64 `json:"outstanding"`
}
type ClaimValuationEvent ¶
type ClaimValuationEvent struct {
Sequence int `json:"sequence"`
Type string `json:"type"`
EffectiveAt string `json:"effective_at"`
RecordedAt string `json:"recorded_at"`
PreviousStatus *string `json:"previous_status"`
NextStatus *string `json:"next_status"`
ReasonCode *string `json:"reason_code"`
EvidenceReferences []string `json:"evidence_references"`
}
ClaimValuationEvent records one Claim fact with both its business time and the knowledge time at which Heyrafiki persisted it.
type ClaimValuationOptions ¶
type ClaimValuationOptions struct {
// ValuationAt is an inclusive RFC 3339 cutoff. Heyrafiki returns only the facts
// whose business time and knowledge time both fall on or before it.
ValuationAt string
}
ClaimValuationOptions supplies the knowledge cutoff required by a Claim valuation.
type Client ¶
type Client struct {
API *APIService
Practitioners *PractitionerService
Bookings *BookingService
Sessions *SessionService
EligibilityChecks *EligibilityCheckService
Coverages *CoverageService
CoverageBatches *CoverageBatchService
Claims *ClaimService
Remittances *RemittanceService
WebhookEndpoints *WebhookEndpointService
// contains filtered or unexported fields
}
Client is a concurrency-safe client for the Heyrafiki API.
type CoverageAmountLimit ¶
type CoverageBatchInput ¶
type CoverageBatchInput struct {
ContractVersion string `json:"contract_version"`
BatchReference string `json:"batch_reference"`
BatchVersion string `json:"batch_version"`
SourceContractReference string `json:"source_contract_reference"`
GeneratedAt string `json:"generated_at"`
Records []CoverageBatchRecordInput `json:"records"`
}
type CoverageBatchOptions ¶
CoverageBatchOptions supplies the replay controls required by Coverage batch ingestion.
type CoverageBatchRecordInput ¶
type CoverageBatchRecordInput struct {
CoverageReference string `json:"coverage_reference"`
RecordVersion string `json:"record_version"`
TenantReference string `json:"tenant_reference"`
MemberReference string `json:"member_reference"`
PlanName string `json:"plan_name"`
ServiceCode string `json:"service_code"`
Status CoverageStatus `json:"status"`
Currency Currency `json:"currency"`
AmountLimit int64 `json:"amount_limit"`
RemainingSessions int `json:"remaining_sessions"`
AuthorizationRequired bool `json:"authorization_required"`
CoordinationPriority *int `json:"coordination_priority"`
ValidFrom string `json:"valid_from"`
ValidUntil string `json:"valid_until"`
}
type CoverageBatchResult ¶
type CoverageBatchResult struct {
Object string `json:"object"`
BatchReference string `json:"batch_reference"`
ArtifactSHA256 string `json:"artifact_sha256"`
Total int `json:"total"`
Recorded int `json:"recorded"`
Replayed int `json:"replayed"`
Observations []CoverageObservation `json:"observations"`
}
type CoverageBatchService ¶
type CoverageBatchService struct {
// contains filtered or unexported fields
}
CoverageBatchService records replay-safe payer Coverage batches.
func (*CoverageBatchService) Record ¶
func (service *CoverageBatchService) Record(ctx context.Context, input CoverageBatchInput, options CoverageBatchOptions) (*CoverageBatchResult, error)
Record stores a payer Coverage batch with replay-safe artifact controls.
type CoverageObservation ¶
type CoverageObservation struct {
ID string `json:"id"`
Object string `json:"object"`
CoverageID string `json:"coverage_id"`
Source string `json:"source"`
SourceContractReference string `json:"source_contract_reference"`
ExternalCoverageReference string `json:"external_coverage_reference"`
SourceVersion string `json:"source_version"`
SnapshotVersion int `json:"snapshot_version"`
Status CoverageStatus `json:"status"`
ServiceCode string `json:"service_code"`
AmountLimit CoverageAmountLimit `json:"amount_limit"`
RemainingSessions int `json:"remaining_sessions"`
AuthorizationRequired bool `json:"authorization_required"`
CoordinationPriority *int `json:"coordination_priority"`
ValidFrom string `json:"valid_from"`
ValidUntil string `json:"valid_until"`
ObservedAt string `json:"observed_at"`
}
type CoverageObservationInput ¶
type CoverageObservationInput struct {
SourceContractReference string `json:"source_contract_reference"`
ExternalCoverageReference string `json:"external_coverage_reference"`
SourceVersion string `json:"source_version"`
TenantReference string `json:"tenant_reference"`
MemberReference string `json:"member_reference"`
PlanName string `json:"plan_name"`
ServiceCode string `json:"service_code"`
Status CoverageStatus `json:"status"`
Currency Currency `json:"currency"`
AmountLimit int64 `json:"amount_limit"`
RemainingSessions int `json:"remaining_sessions"`
AuthorizationRequired bool `json:"authorization_required"`
CoordinationPriority *int `json:"coordination_priority"`
ValidFrom string `json:"valid_from"`
ValidUntil string `json:"valid_until"`
ObservedAt string `json:"observed_at"`
EvidenceReferences []string `json:"evidence_references"`
}
type CoverageService ¶
type CoverageService struct {
// contains filtered or unexported fields
}
CoverageService records payer Coverage observations.
func (*CoverageService) Record ¶
func (service *CoverageService) Record(ctx context.Context, input CoverageObservationInput, options WriteOptions) (*CoverageObservation, error)
Record stores a payer Coverage observation with a caller-owned idempotency key.
type CoverageStatus ¶
type CoverageStatus string
const ( CoverageStatusActive CoverageStatus = "active" CoverageStatusPaused CoverageStatus = "paused" CoverageStatusExhausted CoverageStatus = "exhausted" CoverageStatusExpired CoverageStatus = "expired" )
type Currency ¶
type Currency string
Currency is an ISO 4217 currency accepted by the version 1 contract.
type DeniedPreauthorizationDecisionInput ¶
type DeniedPreauthorizationDecisionInput struct {
}
type EligibilityAmount ¶
type EligibilityCheck ¶
type EligibilityCheck struct {
ID string `json:"id"`
Object string `json:"object"`
Status string `json:"status"`
ReasonCodes []string `json:"reason_codes"`
Service EligibilityService `json:"service"`
Amount EligibilityAmount `json:"amount"`
AuthorizationRequired bool `json:"authorization_required"`
RemainingSessions *int `json:"remaining_sessions"`
CoverageValidUntil *string `json:"coverage_valid_until"`
CheckedAt string `json:"checked_at"`
}
type EligibilityCheckInput ¶
type EligibilityCheckService ¶
type EligibilityCheckService struct {
// contains filtered or unexported fields
}
EligibilityCheckService creates and reads Benefit eligibility checks.
func (*EligibilityCheckService) Create ¶
func (service *EligibilityCheckService) Create(ctx context.Context, input EligibilityCheckInput, options WriteOptions) (*EligibilityCheck, error)
Create checks Benefit eligibility with a caller-owned idempotency key.
func (*EligibilityCheckService) Retrieve ¶
func (service *EligibilityCheckService) Retrieve(ctx context.Context, eligibilityCheckID string) (*EligibilityCheck, error)
Retrieve returns one eligibility check visible to the project.
type EligibilityService ¶
type ListOptions ¶
type ListOptions struct {
Limit int
}
ListOptions controls paginated list operations.
type Option ¶
type Option func(*clientConfig) error
Option configures a Client.
func WithAuthStyle ¶
WithAuthStyle selects bearer or x-api-key authentication.
func WithBaseURL ¶
WithBaseURL replaces the API base URL. HTTPS is required except for loopback test servers.
func WithHTTPClient ¶
WithHTTPClient supplies the HTTP client used for all requests.
func WithMaxResponseSize ¶
WithMaxResponseSize limits response bodies read into memory.
func WithRetryPolicy ¶
func WithRetryPolicy(policy RetryPolicy) Option
WithRetryPolicy replaces the default retry policy.
func WithUserAgent ¶
WithUserAgent appends a caller identifier to the SDK user agent.
type PaymentSource ¶
type PaymentSource string
PaymentSource identifies how a Session is funded.
const ( PaymentSourceSelfPay PaymentSource = "self_pay" PaymentSourceCovered PaymentSource = "covered" )
type PolicyReference ¶
type Practitioner ¶
type PractitionerAvailability ¶
type PractitionerAvailability struct {
Object string `json:"object"`
PractitionerID string `json:"practitioner_id"`
Timezone string `json:"timezone"`
WeeklyHours []AvailabilityWindow `json:"weekly_hours"`
}
type PractitionerList ¶
type PractitionerList struct {
Object string `json:"object"`
Data []Practitioner `json:"data"`
HasMore bool `json:"has_more"`
}
type PractitionerLocation ¶
type PractitionerService ¶
type PractitionerService struct {
// contains filtered or unexported fields
}
PractitionerService discovers Practitioners and availability.
func (*PractitionerService) Availability ¶
func (service *PractitionerService) Availability(ctx context.Context, practitionerID string) (*PractitionerAvailability, error)
Availability returns a Practitioner's weekly availability.
func (*PractitionerService) List ¶
func (service *PractitionerService) List(ctx context.Context, options *ListOptions) (*PractitionerList, error)
List returns visible Practitioners.
func (*PractitionerService) Retrieve ¶
func (service *PractitionerService) Retrieve(ctx context.Context, practitionerID string) (*Practitioner, error)
Retrieve returns one visible Practitioner.
type Preauthorization ¶
type Preauthorization struct {
}
type PreauthorizationAmount ¶
type PreauthorizationAmount struct {
}
type PreauthorizationDecision ¶
type PreauthorizationDecision struct {
}
type PreauthorizationDecisionInput ¶
type PreauthorizationDecisionInput interface {
// contains filtered or unexported methods
}
PreauthorizationDecisionInput is implemented by the approved and denied decision variants.
type PreauthorizationInput ¶
type PreauthorizationInput struct {
}
type PreauthorizationService ¶
type PreauthorizationService struct {
// contains filtered or unexported fields
}
PreauthorizationService creates, reads and decides pre-authorizations.
func (*PreauthorizationService) Create ¶
func (service *PreauthorizationService) Create(ctx context.Context, input PreauthorizationInput, options WriteOptions) (*Preauthorization, error)
Create requests pre-authorization with a caller-owned idempotency key.
func (*PreauthorizationService) Decide ¶
func (service *PreauthorizationService) Decide(ctx context.Context, preauthorizationID string, input PreauthorizationDecisionInput, options WriteOptions) (*Preauthorization, error)
Decide records an approved or denied pre-authorization decision.
func (*PreauthorizationService) Retrieve ¶
func (service *PreauthorizationService) Retrieve(ctx context.Context, preauthorizationID string) (*Preauthorization, error)
Retrieve returns one pre-authorization visible to the project.
type Remittance ¶
type Remittance struct {
ID string `json:"id"`
Object string `json:"object"`
Status string `json:"status"`
PayerReference string `json:"payer_reference"`
Amount RemittanceAmount `json:"amount"`
Allocations []RemittanceAllocation `json:"allocations"`
ReceivedAt string `json:"received_at"`
ReconciledAt *string `json:"reconciled_at"`
}
type RemittanceAllocation ¶
type RemittanceAmount ¶
type RemittanceInput ¶
type RemittanceInput struct {
PayerReference string `json:"payer_reference"`
Currency Currency `json:"currency"`
ReceivedAt string `json:"received_at"`
Allocations []RemittanceAllocationInput `json:"allocations"`
}
type RemittanceList ¶
type RemittanceList struct {
Object string `json:"object"`
Data []Remittance `json:"data"`
HasMore bool `json:"has_more"`
}
type RemittanceService ¶
type RemittanceService struct {
// contains filtered or unexported fields
}
RemittanceService creates and reads remittance advice.
func (*RemittanceService) Create ¶
func (service *RemittanceService) Create(ctx context.Context, input RemittanceInput, options WriteOptions) (*Remittance, error)
Create records remittance advice with a caller-owned idempotency key.
func (*RemittanceService) List ¶
func (service *RemittanceService) List(ctx context.Context, options *ListOptions) (*RemittanceList, error)
List returns remittances visible to the project.
func (*RemittanceService) Retrieve ¶
func (service *RemittanceService) Retrieve(ctx context.Context, remittanceID string) (*Remittance, error)
Retrieve returns one remittance visible to the project.
type RetryPolicy ¶
RetryPolicy controls bounded retries for reads and writes protected by an idempotency key.
func DefaultRetryPolicy ¶
func DefaultRetryPolicy() RetryPolicy
DefaultRetryPolicy returns the SDK's bounded exponential-backoff policy.
type ServicePeriod ¶
type Session ¶
type Session struct {
ID string `json:"id"`
Object string `json:"object"`
PractitionerID string `json:"practitioner_id"`
StartsAt string `json:"starts_at"`
EndsAt string `json:"ends_at"`
Timezone string `json:"timezone"`
Format CareFormat `json:"format"`
Status string `json:"status"`
PaymentSource PaymentSource `json:"payment_source"`
}
type SessionList ¶
type SessionService ¶
type SessionService struct {
// contains filtered or unexported fields
}
SessionService reads Sessions.
func (*SessionService) List ¶
func (service *SessionService) List(ctx context.Context, options *ListOptions) (*SessionList, error)
List returns Sessions visible to the project.
type WebhookDelivery ¶
type WebhookEndpoint ¶
type WebhookEndpointInput ¶
type WebhookEndpointInput struct {
URL string `json:"url"`
Events []WebhookEvent `json:"events"`
}
type WebhookEndpointList ¶
type WebhookEndpointList struct {
Object string `json:"object"`
Data []WebhookEndpoint `json:"data"`
HasMore bool `json:"has_more"`
}
type WebhookEndpointService ¶
type WebhookEndpointService struct {
// contains filtered or unexported fields
}
WebhookEndpointService manages Webhook endpoints and test deliveries.
func (*WebhookEndpointService) Create ¶
func (service *WebhookEndpointService) Create(ctx context.Context, input WebhookEndpointInput) (*WebhookEndpointWithSecret, error)
Create registers a Webhook endpoint and returns its signing secret once.
func (*WebhookEndpointService) Disable ¶
func (service *WebhookEndpointService) Disable(ctx context.Context, endpointID string) (*WebhookEndpoint, error)
Disable disables a Webhook endpoint.
func (*WebhookEndpointService) List ¶
func (service *WebhookEndpointService) List(ctx context.Context, options *ListOptions) (*WebhookEndpointList, error)
List returns Webhook endpoints visible to the project.
func (*WebhookEndpointService) Retrieve ¶
func (service *WebhookEndpointService) Retrieve(ctx context.Context, endpointID string) (*WebhookEndpoint, error)
Retrieve returns one Webhook endpoint visible to the project.
func (*WebhookEndpointService) SendTest ¶
func (service *WebhookEndpointService) SendTest(ctx context.Context, endpointID string) (*WebhookDelivery, error)
SendTest sends a contract-defined test event to a Webhook endpoint.
type WebhookEndpointWithSecret ¶
type WebhookEndpointWithSecret struct {
ID string `json:"id"`
Object string `json:"object"`
URL string `json:"url"`
Events []WebhookEvent `json:"events"`
Status string `json:"status"`
CreatedAt string `json:"created_at"`
DisabledAt *string `json:"disabled_at"`
SigningSecret string `json:"signing_secret"`
}
type WebhookEvent ¶
type WebhookEvent string
const ( WebhookSandboxPing WebhookEvent = "sandbox.ping" WebhookClaimSubmitted WebhookEvent = "claim.submitted" WebhookClaimInformationRequested WebhookEvent = "claim.information_requested" WebhookClaimResubmitted WebhookEvent = "claim.resubmitted" WebhookClaimApproved WebhookEvent = "claim.approved" WebhookClaimPartiallyApproved WebhookEvent = "claim.partially_approved" WebhookClaimDenied WebhookEvent = "claim.denied" WebhookClaimSettled WebhookEvent = "claim.settled" WebhookRemittanceReconciled WebhookEvent = "remittance.reconciled" )
type WriteOptions ¶
type WriteOptions struct {
IdempotencyKey string
}
WriteOptions supplies the caller-owned idempotency key required by a write operation.
Directories
¶
| Path | Synopsis |
|---|---|
|
examples
|
|
|
covered-care
command
Command covered-care demonstrates the typed eligibility and Booking flow with caller-owned idempotency keys.
|
Command covered-care demonstrates the typed eligibility and Booking flow with caller-owned idempotency keys. |